branch: elpa/llama
commit 5c454f1a83c698668942603e595cec36a5211768
Author: Jonas Bernoulli <[email protected]>
Commit: Jonas Bernoulli <[email protected]>
Fix typo
---
README.md | 2 +-
llama.el | 4 ++--
2 files changed, 3 insertions(+), 3 deletions(-)
diff --git a/README.md b/README.md
index caa7d2daf2..24d1bc8ccb 100644
--- a/README.md
+++ b/README.md
@@ -44,6 +44,6 @@ which expands to:
(foo %1 (bar &3) %*))
```
-The name `##` was choosen because that allows (optionally)
+The name `##` was chosen because that allows (optionally)
omitting the whitespace between it and the following symbol.
It also looks similar to `#'function`.
diff --git a/llama.el b/llama.el
index ca7ffbfa9d..a5f124966f 100644
--- a/llama.el
+++ b/llama.el
@@ -65,7 +65,7 @@
;; (lambda (%1 _%2 &optional %3 &rest %*)
;; (foo %1 (bar %3) %*))
;; The name `##' was choosen because that allows (optionally)
;; omitting the whitespace between it and the following symbol.
;; It also looks similar to #'function.
@@ -108,7 +108,7 @@ which expands to:
(lambda (%1 _%2 &optional &3 &rest %*)
(foo %1 (bar &3) %*))
-The name `##' was choosen because that allows (optionally)
+The name `##' was chosen because that allows (optionally)
omitting the whitespace between it and the following symbol.
It also looks a bit like #\\='function."
(unless (symbolp fn)
@@ -65,7 +65,7 @@
;; (lambda (%1 _%2 &optional %3 &rest %*)
;; (foo %1 (bar %3) %*))
-;; The name `##' was choosen because that allows (optionally)
+;; The name `##' was chosen because that allows (optionally)
;; omitting the whitespace between it and the following symbol.
;; It also looks similar to #'function.